//---------------------------------------------------------------------------------
/// \file	CreateSimpleNode.h
/// \author	Rob Bateman [robthebloke@hotmail.com]
/// \date	2-7-2004
/// \brief	
///
//---------------------------------------------------------------------------------

#ifndef __CREATE_SIMPLE_NODE_COMMAND__H__
#define __CREATE_SIMPLE_NODE_COMMAND__H__

	#ifdef WIN32
		#define NT_PLUGIN
		#pragma once
	#endif

	// include any maya headers we need.
	#include "SimpleNode.h"
	#include <maya/MPxCommand.h>
	#include <maya/MSyntax.h>

	class CreateSimpleNode
		: public MPxCommand {
	public:

		/// \brief	This function is overidden to tell maya whether this mel command
		/// 		can be undone.
		/// \return	true	-	this func can be undone
		///
		virtual bool isUndoable() const ;

		/// \brief	This function is called when you mel command is executed. The function
		/// 		recieves the list of arguments passed to the command by mel. The actual
		/// 		'doing' part of the function happens in redoIt(). (which this function
		/// 		actually calls)
		/// \param	args	-	the list of arguments
		/// \param	An error code.
		///
		MStatus doIt( const MArgList& args );

		/// \brief	This function is called when the command needs to be re-done.
		/// \param	An error code.
		///
		MStatus redoIt();

		/// \brief	This function is called to undo the last action performed by the command
		/// \param	An error code.
		///
		MStatus undoIt();


		/// \brief	this function is called by maya to return a new instance of our mel function
		/// \return	the new mel command object
		///
		static void* creator();

		/// \brief	This function must create a new syntax description for the mel command.
		/// 		This allows us to simplify the parsing of arguments passed to the function
		/// 		call.
		/// \note	If in mel you type...
		///
		/// 			help createSimpleNode
		///
		///			... it should output the following to the script editor
		///
		/// 			Synopsis: createSimpleNode [flags]
		/// 			Flags:
		/// 			   -h -help
		///
		/// 		Maya uses the MSyntax object we create to produce this information.
		///
		static MSyntax newSyntax();

	private:

		/// the name of the simple node created. We store this so we delete it later
		MString m_Name;
	};

#endif
