//---------------------------------------------------------------------------------
/// \file	PluginMain.cpp
/// \author	Rob Bateman
/// \date	17-11-04
/// \brief
/// 
//---------------------------------------------------------------------------------

#include "CreateSimpleNode.h"
#include "SimpleNode.h"
#include <maya/MFnPlugin.h>

// required to link the libraries under VisualC++/Win32
#ifdef WIN32
	#pragma comment(lib,"Foundation.lib")
	#pragma comment(lib,"OpenMaya.lib")
	#pragma comment(lib,"OpenMayaFx.lib")
	#pragma comment(lib,"OpenMayaUi.lib")
	#pragma comment(lib,"Image.lib")
	#pragma comment(lib,"OpenMayaAnim.lib")
#endif

// under WIN32 we have to 'export' these functions so that they are visible
// inside the dll. If maya can't see the functions, it can't load the plugin!
#ifdef WIN32
	#define EXPORT __declspec(dllexport)
#else
	#define EXPORT
#endif


/// \brief	This function is called once when our plugin is loaded. We can use
///			it to register any custom nodes, mel functions etc.
/// \param	obj	-	a handle to the loaded plugin
/// \return	an MStatus error code
///
EXPORT MStatus initializePlugin( MObject obj )
{
	MStatus   status;

	MFnPlugin plugin( obj, "Rob Bateman", "1.0", "Any");

	// register the simple node
	status = plugin.registerNode(SimpleNode::m_TypeName,
								 SimpleNode::m_TypeId,
								 SimpleNode::creator,
								 SimpleNode::initialize,
								 MPxNode::kDependNode );

	if(status != MS::kSuccess)
		return status;

	// register the mel function to create a node
	status = plugin.registerCommand("createSimpleNode",
								 CreateSimpleNode::creator,
								 CreateSimpleNode::newSyntax );

	return status;
}

/// \brief	This function is called once when our plugin is unloaded. We need
/// 		to tell maya which mel funcs, nodes etc we are removing.
/// \param	obj	-	a handle to the loaded plugin
/// \return	an MStatus error code
///
EXPORT MStatus uninitializePlugin( MObject obj)
{
	MFnPlugin plugin( obj );

	// Unregister the simple node
	MStatus status = plugin.deregisterNode( SimpleNode::m_TypeId );

	if(status != MS::kSuccess)
		return status;

	// register the mel function to create a node
	status = plugin.deregisterCommand("createSimpleNode");

	return status;
}
